import { detectIsFunction, $$scope, detectIsArray } from '@dark-engine/core';
class SyntheticEvent {
  type = '';
  sourceEvent = null;
  target = null;
  propagation = true;
  constructor(options) {
    this.type = options.sourceEvent.type;
    this.sourceEvent = options.sourceEvent;
    this.target = options.target;
  }
  stopPropagation() {
    this.propagation = false;
    this.sourceEvent.stopPropagation();
  }
  preventDefault() {
    this.sourceEvent.preventDefault();
  }
  getPropagation() {
    return this.propagation;
  }
}
function delegateEvent(target, eventName, handler) {
  const $scope = $$scope();
  const eventsMap = $scope.getEvents();
  const handlersMap = eventsMap.get(eventName);
  const $handler = detectIsArray(handler) ? e => handler[0](...handler.slice(1), e) : handler;
  if (!handlersMap) {
    const rootHandler = event => {
      const handler = eventsMap.get(eventName).get(event.target);
      const target = event.target;
      let $event = null;
      if (detectIsFunction(handler)) {
        $event = new SyntheticEvent({ sourceEvent: event, target });
        $scope.setIsEventZone(true);
        handler($event);
        $scope.setIsEventZone(false);
      }
      if (target.parentElement) {
        const shouldPropagate = $event ? $event.getPropagation() : true;
        if (shouldPropagate) {
          const constructor = event.constructor;
          target.parentElement.dispatchEvent(new constructor(event.type, event));
        }
      }
    };
    eventsMap.set(eventName, new WeakMap([[target, $handler]]));
    document.addEventListener(eventName, rootHandler, true);
    $scope.addEventUnsubscriber(() => document.removeEventListener(eventName, rootHandler, true));
  } else {
    handlersMap.set(target, $handler);
  }
}
const detectIsEvent = attrName => attrName.startsWith('on');
const getEventName = attrName => attrName.slice(2, attrName.length).toLowerCase();
export { SyntheticEvent, delegateEvent, detectIsEvent, getEventName };
//# sourceMappingURL=events.js.map
